IVRE Web UI

Results

You can upload XML results from Nmap (`-oX`) or JSON results from `ivre scancli --json`. Files can be compressed with bzip2 or gzip.

Categories

Categories are arbitrary strings that can be used to define your scan (targets, type of scan, etc.).

Example: `Country-XX,Standard`, or `AS-12345,Fast`.

If you are authenticated, your username will be set as a category in addition to thoses specified. If you decide to share those results with other users of this instance (see below), the category "Shared" will be set in addition to thoses specified (and if you include a category "Shared", the results will be available to other users of this instance, regardless of "Make the results public").

Source

The source is an arbitrary string that can be used to define from where you have run the scan (Network, etc.). This field is mandatory.

Example: `Provider-Scanner0`, or `ISP-192.168.0.1`.

Share these results

By checking this, you will make the uploaded scan results available to other users of this instance.

This is a public instance. If you have not checked "Share these results", we will do our best to keep your results safe, but we can offer no guarantee. For this reason, you should only upload non-sensitive results.

I have read and I agree.

# This instance do not authorize uploads (this is the default)

To change this, set`WEB_UPLOAD_OK` to `True` in `ivre.conf`.